@@ -12,12 +12,22 @@ from ...util.retry import DEFAULT_RETRY_ARGUMENTS
 
 def _get_kwargs(
     *,
+    client: httpx.Client,
     json_body: CreateReservationRequest,
 ) -> Dict[str, Any]:
+    url = "{}/v1/reservations".format(client.base_url)
+
+    headers = {k: v for (k, v) in client.headers.items()}
+    cookies = {k: v for (k, v) in client.cookies}
 
     json_json_body = json_body.to_dict()
 
     return {
+        "method": "post",
+        "url": url,
+        "headers": headers,
+        "cookies": cookies,
+        "timeout": client.timeout,
         "json": json_json_body,
     }
 
@@ -46,17 +56,34 @@ def sync(
     *,
     client: httpx.Client,
     json_body: CreateReservationRequest,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
-    url = "/v1/reservations"
+    """Create Reservation
+
+     Create a new reservation.
+
+    The following precedence applies when specifying the reservation subject account ID and type:
+    * request body `accountId` field, or if unset then `X-QCS-ACCOUNT-ID` header, or if unset then
+    requesting user's ID.
+    * request body `accountType` field, or if unset then `X-QCS-ACCOUNT-TYPE` header, or if unset then
+    \"user\" type.
+
+    Args:
+        json_body (CreateReservationRequest):
+
+    Returns:
+        Response[Reservation]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "post",
-        url,
         **kwargs,
     )
+
     return _build_response(response=response)
 
 
@@ -65,18 +92,16 @@ def sync_from_dict(
     *,
     client: httpx.Client,
     json_body_dict: Dict,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
     json_body = CreateReservationRequest.from_dict(json_body_dict)
 
-    url = "/v1/reservations"
-
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
+    kwargs.update(httpx_request_kwargs)
     response = client.request(
-        "post",
-        url,
         **kwargs,
     )
 
@@ -88,14 +113,33 @@ async def asyncio(
     *,
     client: httpx.AsyncClient,
     json_body: CreateReservationRequest,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
-    url = "/v1/reservations"
+    """Create Reservation
+
+     Create a new reservation.
+
+    The following precedence applies when specifying the reservation subject account ID and type:
+    * request body `accountId` field, or if unset then `X-QCS-ACCOUNT-ID` header, or if unset then
+    requesting user's ID.
+    * request body `accountType` field, or if unset then `X-QCS-ACCOUNT-TYPE` header, or if unset then
+    \"user\" type.
+
+    Args:
+        json_body (CreateReservationRequest):
+
+    Returns:
+        Response[Reservation]
+    """
 
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = await client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
 
@@ -105,15 +149,17 @@ async def asyncio_from_dict(
     *,
     client: httpx.AsyncClient,
     json_body_dict: Dict,
+    httpx_request_kwargs: Dict[str, Any] = {},
 ) -> Response[Reservation]:
     json_body = CreateReservationRequest.from_dict(json_body_dict)
 
-    url = "/v1/reservations"
-
     kwargs = _get_kwargs(
+        client=client,
         json_body=json_body,
     )
-
-    response = await client.request("post", url, **kwargs)
+    kwargs.update(httpx_request_kwargs)
+    response = client.request(
+        **kwargs,
+    )
 
     return _build_response(response=response)
